# gorilla-career-advising

Example input: 
```
get_job_from_linkedin(
    "abc@efg.xyz", 
    "password", 
    "new grad software engineer", 
    "08540" // or San Francisco,
    "entry level"
    )
```

Example return:
```
"{3674915679": 
    "{
        \"job title\": \"\ Staff Machine Learning Engineer - New Verticals Search\ \", 
        \"salary\": \"\$176,000/yr - $238,000/yr (from job description) \\u00b7 Full-time\\n\\n\", 
        \"company size\": \"\n10,001+ employees \\u00b7 Software Development\\n\\n\", 
        \"job description\": \"\ About the job\ 
        }
    }
```